@@ -1,4 +1,5 @@
 use crate::{ApubObject, Crud, DeleteableOrRemoveable, Likeable, Saveable};
+use chrono::NaiveDateTime;
 use diesel::{dsl::*, result::Error, *};
 use lemmy_db_schema::{
   naive_now,
@@ -50,6 +51,7 @@ pub trait Comment_ {
     comment_id: CommentId,
     new_content: &str,
   ) -> Result<Comment, Error>;
+  fn upsert(conn: &PgConnection, comment_form: &CommentForm) -> Result<Comment, Error>;
 }
 
 impl Comment_ for Comment {
@@ -133,6 +135,16 @@ impl Comment_ for Comment {
       .set((content.eq(new_content), updated.eq(naive_now())))
       .get_result::<Self>(conn)
   }
+
+  fn upsert(conn: &PgConnection, comment_form: &CommentForm) -> Result<Comment, Error> {
+    use lemmy_db_schema::schema::comment::dsl::*;
+    insert_into(comment)
+      .values(comment_form)
+      .on_conflict(ap_id)
+      .do_update()
+      .set(comment_form)
+      .get_result::<Self>(conn)
+  }
 }
 
 impl Crud for Comment {
@@ -168,21 +180,14 @@ impl Crud for Comment {
 }
 
 impl ApubObject for Comment {
-  type Form = CommentForm;
+  fn last_refreshed_at(&self) -> Option<NaiveDateTime> {
+    None
+  }
+
   fn read_from_apub_id(conn: &PgConnection, object_id: &DbUrl) -> Result<Self, Error> {
     use lemmy_db_schema::schema::comment::dsl::*;
     comment.filter(ap_id.eq(object_id)).first::<Self>(conn)
   }
-
-  fn upsert(conn: &PgConnection, comment_form: &CommentForm) -> Result<Self, Error> {
-    use lemmy_db_schema::schema::comment::dsl::*;
-    insert_into(comment)
-      .values(comment_form)
-      .on_conflict(ap_id)
-      .do_update()
-      .set(comment_form)
-      .get_result::<Self>(conn)
-  }
 }
 
 impl Likeable for CommentLike {
